@@ -2,12 +2,12 @@ from __future__ import absolute_import
 import logging
 import sys
 import config
-import irc.connection
 from errbot.backends.base import Message, build_message, build_text_html_message_pair
 from errbot.errBot import ErrBot
 from errbot.utils import RateLimited
 
 try:
+    import irc.connection
     from irc.bot import SingleServerIRCBot
 except ImportError as _:
     logging.exception("Could not start the IRC backend")
@@ -26,10 +26,12 @@ except ImportError as _:
 
 
 class IRCConnection(SingleServerIRCBot):
-    def __init__(self, callback, nickname, server, port=6667, ssl=False, password=None):
+    def __init__(self, callback, nickname, server, port=6667, ssl=False, password=None, username=None):
         self.use_ssl = ssl
         self.callback = callback
-        super().__init__([(server, port, password)], nickname, nickname)
+        if username is None:
+            username = nickname
+        super().__init__([(server, port, password)], nickname, username)
 
     def _dispatcher(self, c, e):
         super()._dispatcher(c, e)
@@ -63,7 +65,9 @@ class IRCConnection(SingleServerIRCBot):
 
     def send_message(self, mess):
         msg_func = self.send_private_message if mess.typ == 'chat' else self.send_public_message
-        if mess.typ == 'chat' and mess.getTo().resource:  # if this is a response in private of a public message take the recipient in the resource instead of the incoming chatroom
+        # If this is a response in private of a public message take the recipient in
+        # the resource instead of the incoming chatroom
+        if mess.typ == 'chat' and mess.getTo().resource:
             to = mess.getTo().resource
         else:
             to = mess.getTo().node
@@ -80,10 +84,10 @@ class IRCConnection(SingleServerIRCBot):
 
 
 class IRCBackend(ErrBot):
-    def __init__(self, nickname, server, port=6667, password=None, ssl=False):
+    def __init__(self, nickname, server, port=6667, password=None, ssl=False, username=None):
         self.jid = nickname + '@' + server
         super(IRCBackend, self).__init__()
-        self.conn = IRCConnection(self, nickname, server, port, ssl, password)
+        self.conn = IRCConnection(self, nickname, server, port, ssl, password, username)
 
     def serve_forever(self):
         try:
